/**
    @file appdata.h

    Data structures for the whole application.

    Copyright (c) 2004-2005 Nokia Corporation.
	
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA
*/


#ifndef APPDATA_H
#define APPDATA_H


#include <aconf.h>

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gconf/gconf-client.h>
#include <libgnomevfs/gnome-vfs-monitor.h>
#include <libgnomevfs/gnome-vfs-volume-monitor.h>
#include <hildon-widgets/hildon-app.h>
#include <hildon-widgets/hildon-appview.h>
#include <hildon-widgets/hildon-file-system-model.h>
#include <libosso.h>
#include <osso-log.h>


typedef struct _RecentItem RecentItem;
typedef struct _AppData   AppData;
typedef struct _AppUIData AppUIData;

typedef enum {
    PDF_VIEWER_STATE_EMPTY,
    PDF_VIEWER_STATE_LOADING,
    PDF_VIEWER_STATE_LOADED,
    PDF_VIEWER_STATE_SAVING
} PDFViewerState;

typedef enum {
    STARTUP_MODE_DEFAULT,
    STARTUP_MODE_URI_REQUEST,
    STARTUP_MODE_STATE_DATA
} PDFViewerStartupMode;

/* Recent Item */
struct _RecentItem {
    gchar                 *uri;
    GnomeVFSMonitorHandle *monitor_handle;
};


/* Application data */
struct _AppData {
    AppUIData             *app_ui_data;
    osso_context_t        *osso_context;
    GConfClient           *gc_client;
    GSList                *recent_list;

    GnomeVFSVolumeMonitor *volume_monitor;
    gchar                 *mmc_uri;

    PDFViewerState        state;
    PDFViewerStartupMode  mode;

    gboolean              low_memory;
};


/* FLAGS */
#define PDF_FLAGS_SET(a,b)    ((a) |= (b))
#define PDF_FLAGS_UNSET(a,b)  ((a) &= ~(b))
#define PDF_FLAGS_TOGGLE(a,b) ((a) ^= (b))
#define PDF_FLAGS_IS_SET(a,b) ((a) & (b))

typedef enum {
  PDF_FLAGS_NONE                = 0,
  PDF_FLAGS_RENDERING           = 1,
  PDF_FLAGS_FULLSCREEN          = 1 << 1,
  PDF_FLAGS_BUTTON_DOWN         = 1 << 2,
  PDF_FLAGS_PANNING             = 1 << 3,
  PDF_FLAGS_SHOW_IMAGES         = 1 << 4,
  PDF_FLAGS_SELECT_KEY_ALLOWED  = 1 << 5,
  PDF_FLAGS_BACKGROUNDED        = 1 << 6,
  PDF_FLAGS_PAGE_ERROR          = 1 << 7
} PDFFlags;

/* Application UI data */
struct _AppUIData {
    /* Pointer back to AppData (parent structure) */
    AppData       *app_data;

    /* View items */
    HildonApp     *app;
    HildonAppView *app_view;

    /* UI Manager */
    GtkUIManager  *ui_manager;

    /* Actions are available through ui manager,
       toolbar and menu through appview */

    /* Toolbar widget */
    GtkToolbar    *toolbar;

    /* Toolbar label widgets */
    GtkWidget     *current_page;
    GtkWidget     *total_pages;
    GtkWidget     *current_page_item;
    GtkWidget     *current_zoom_item;
    GtkWidget     *current_zoom_value;
    GtkWidget     *image_button;

    GtkWidget     *img_images_on;
    GtkWidget     *img_images_off;

    /* Application area widgets */
    GtkWidget     *scrolled_window;
    GtkWidget     *layout;
    GtkWidget     *page_image;

    /* scrollbar widgets */
    GtkWidget     *hscroll;
    GtkWidget     *vscroll;

    /* The last pointer position where it was updated */
    gint           lastx;
    gint           lasty;

    /* Current DPI */
    gdouble        dpi;

  int /* PDFFlags*/       flags;
};

#endif				/* APPDATA_H */
